summaryrefslogtreecommitdiffstats
path: root/multimedia/mps-youtube/files/patch-setup.py
blob: 3e3c3176aef88a3c55b6545a62a83723410ab9d6 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
--- setup.py.orig	2016-01-01 22:16:41 UTC
+++ setup.py
@@ -64,8 +64,8 @@ options = dict(
     long_description=open("README.rst").read()
 )
 
-if sys.platform.startswith('linux'):
-    # Install desktop file. Required for mpris on Ubuntu
+if sys.platform.startswith(('freebsd', 'linux')):
+    # Install desktop file. Required for mpris on FreeBSD and Ubuntu
     options['data_files'].append(('share/applications/', ['mps-youtube.desktop']))
 
 if os.name == "nt":
OpenPOWER on IntegriCloud